==> opennebula_3.4.1.orig.tar.gz: opennebula-3.4.1/include/HostTemplate.h <==
/* -------------------------------------------------------------------------- */
/* Copyright 2002-2012, OpenNebula Project Leads (OpenNebula.org)             */
/*                                                                            */
/* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
/* not use this file except in compliance with the License. You may obtain    */
/* a copy of the License at                                                   */
/*                                                                            */
/* http://www.apache.org/licenses/LICENSE-2.0                                 */
/*                                                                            */
/* Unless required by applicable law or agreed to in writing, software        */
/* distributed under the License is distributed on an "AS IS" BASIS,          */
/* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   */
/* See the License for the specific language governing permissions and        */
/* limitations under the License.                                             */
/* -------------------------------------------------------------------------- */

#ifndef HOST_TEMPLATE_H_
#define HOST_TEMPLATE_H_

#include "Template.h"

using namespace std;

/**
 *  Host Template class, it represents the attributes of a Host
 */
class HostTemplate : public Template
{
public:
    HostTemplate() : Template(true,'=',"TEMPLATE"){};

    ~HostTemplate(){};

};

/* -------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------- */

#endif /*HOST_TEMPLATE_H_*/

==> opennebula_4.10.1.orig.tar.gz: opennebula-4.10.1/include/HostTemplate.h <==
/* -------------------------------------------------------------------------- */
/* Copyright 2002-2014, OpenNebula Project (OpenNebula.org), C12G Labs        */
/*                                                                            */
/* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
/* not use this file except in compliance with the License. You may obtain    */
/* a copy of the License at                                                   */
/*                                                                            */
/* http://www.apache.org/licenses/LICENSE-2.0                                 */
/*                                                                            */
/* Unless required by applicable law or agreed to in writing, software        */
/* distributed under the License is distributed on an "AS IS" BASIS,          */
/* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   */
/* See the License for the specific language governing permissions and        */
/* limitations under the License.                                             */
/* -------------------------------------------------------------------------- */

#ifndef HOST_TEMPLATE_H_
#define HOST_TEMPLATE_H_

#include "Template.h"

using namespace std;

/**
 *  Host Template class, it represents the attributes of a Host
 */
class HostTemplate : public Template
{
public:
    HostTemplate() : Template(false,'=',"TEMPLATE"){};

    ~HostTemplate(){};

};

/* -------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------- */

#endif /*HOST_TEMPLATE_H_*/
